@@ -321,7 +321,7 @@ class Client(object):
         return resp.json()["data"]
 
     def get_kline_history(
-        self, begin, end=None, interval:str="1day", msg:bool=False, warning:bool=True,
+        self, tickers, begin, end=None, interval:str="1day", msg:bool=False, warning:bool=True,
     ) -> pd.DataFrame:
         """
         Query historic OHLC(V) data for a ticker or list of tickers 
@@ -353,7 +353,7 @@ class Client(object):
             end = dt.datetime.utcnow()
 
         if isinstance(tickers, str):    
-            tickers = [tickers]    
+            tickers = [tickers]
 
         paganated_ranges = _parse_interval(begin, end, interval)
         unix_ranges = []    # This list will hold paganated unix epochs
